<?php
/**
 * @package Catch Themes
 * @subpackage Catch Box
 * @since Catch Box 3.6.7
 */


if( ! function_exists( 'catchbox_is_favicon_active' ) ) :
	/**
	* Return true if no core site icon is present
	*
	* @since Catch Box 3.6.7
	*/
	function catchbox_is_site_icon_active( $control ) {
		//Check if has_site_icon function exists. If it does not, WP version is less than 4.3
		if ( function_exists( 'has_site_icon' ) ) { 
			//Return true if core site icon is not present, else return false
			return !has_site_icon();
		}
		else {		
			return true;
		}
	}
endif;


if( ! function_exists( 'catchbox_is_feed_url_present' ) ) :
	/**
	* Return true if feed url is present
	*
	* @since Catch Box 3.6.7
	*/
	function catchbox_is_feed_url_present( $control ) {
		$options = catchbox_get_theme_options();
		
		return ( isset( $options['feed_url'] ) && '' != $options['feed_url'] );
	}
endif;


if( ! function_exists( 'catchbox_is_header_code_present' ) ) :
	/**
	* Return true if header code is present
	*
	* @since Catch Box 3.6.7
	*/
	function catchbox_is_header_code_present( $control ) {
		$options = catchbox_get_theme_options();
		
		return ( isset( $options['tracker_header'] ) && '' != $options['tracker_header'] );
	}
endif;


if( ! function_exists( 'catchbox_is_footer_code_present' ) ) :
	/**
	* Return true if footer code is present
	*
	* @since Catch Box 3.6.7
	*/
	function catchbox_is_footer_code_present( $control ) {
		$options = catchbox_get_theme_options();

		return ( isset( $options['tracker_footer'] ) && '' != $options['tracker_footer'] );
	}
endif;


if( ! function_exists( 'catchbox_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchbox_options[enable_slider]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) );
	}
endif;

if( ! function_exists( 'catchbox_is_post_slider_active' ) ) :
	/**
	* Return true if post slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_post_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchbox_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchbox_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'post-slider' == $type );
	}
endif;

if( ! function_exists( 'catchbox_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_page_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchbox_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchbox_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'page-slider' == $type );
	}
endif;

if( ! function_exists( 'catchbox_is_image_slider_active' ) ) :
	/**
	* Return true if image slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_image_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchbox_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchbox_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'image-slider' == $type );
	}
endif;


if( ! function_exists( 'catchbox_is_category_slider_active' ) ) :
	/**
	* Return true if category slider is active
	*
	* @since Catch Box 4.4
	*/
	function catchbox_is_category_slider_active( $control ) {
		global $wp_query;
		
		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts'); 

		$enable = $control->manager->get_setting( 'catchbox_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catchbox_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'category-slider' == $type );
	}
endif;